/*

Fr 10. Mär 17:36:27 CET 2023
Fr 14. Apr 08:51:56 CEST 2023	fixed break if nullbyte line
Di 25. Apr 21:21:53 CEST 2023	flush stdout
Di 25. Apr 21:49:03 CEST 2023	fixed reading stdin

reinhard@finalmedia.de
+++ public domain +++

read every line from stdin
calculate cubehash256 of current line
prepend this hash to current line
followed by space (not part of the hash)
and rest of the line including newline
(not part of the hash)
output to stdout


*/

#include <stdio.h>
#include <stdlib.h>
#include <stddef.h>
#include <stdint.h>
#include <string.h>
#include "cubehash.h"


int main()
{
    //FILE *fp;

    char *line = NULL;
    size_t len = 0;
    char separator=' ';

	// CubeHash256, defined as CubeHash16+16/32+32–256, for AHS256;

    int hashlen = 256;
    int revision = 3;

    while ((getline(&line, &len, stdin)) != -1) {

	if (strlen(line)>0) {

	// cubehash implementation needs a filestream
	// we convert our string to virtual memory filestream
	// and ommit newline character and the end of line
	FILE *stream = fmemopen(line, strlen(line)-1, "r");

	if (stream != NULL) {

        uint8_t *hash = cubehash(stream, revision, hashlen);

        for (int i = 0; i < hashlen / 8; i++) {
                printf("%02x", hash[i]);
	}

	printf("%c",separator);
	printf("%s",line);
	fflush(stdout);
	fclose(stream);
	}
	}

    }
    free(line);
    return 0;
}
